# The Sickulator
Link to Issue tracker: https://trello.com/b/rdkSQQiJ/sickulator

Link to repository: https://github.com/JKornberg/Sickulator

# Installation
`pip install sickulator`

Created by: Jack Driscoll, Thomas Hancock, Julia Harbord, Jonah Kornberg, and Dahlia La Pommeray

# Description
The Sickulator is an agent-based simulator made to visually represent the spread of disease in a small city. The user is provided several configurable options to affect the outcome of the "sickulation". 

# References
Kids Can Code - https://www.youtube.com/watch?v=3UxnelT9aCo&list=PLsk-HSGFjnaGQq7ybM8Lgkh5EMxUWPm2i

# Development set up

### Mac OS / Linux

```
python3 -m virtualenv venv
source venv/bin/activate
# If you're using VSCode, make sure your python interpreter is set to 'venv' #
pip install --upgrade pip
pip install -r requirements.txt
cd sickulator
python main.py
```
